<?php
/**
 * ArchivierungsPlugin.class.php
 *
 * Diese Datei enthlt die Hauptklasse des Plugins
 * Dieses Plugin basiert auf PHP5 und steht unter der GPL.
 *
 * @author  	Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package 	IBIT_ArchivierungsPlugin
 * @copyright 	IBIT 2010
 * @version 	1.1
 */

#error_reporting(E_ALL);

// IMPORTS
require_once 'vendor/flexi/flexi.php';
require_once 'classes/ArchivDB.class.php';

/**
 * Hauptklasse des Plugins - erzeugt ein Objekt des Plugins
 *
 * Dient als Frontcontroller fr das Plugin.
 *
 */
class ArchivierungsPlugin extends AbstractStudIPAdministrationPlugin
{
	/**
	 * Objekt der Templateklasse
	 *
	 * @var unknown_type
	 */
	private $template_factory;

	/**
	 * Enter description here...
	 *
	 * @var unknown_type
	 */
	public $user;

	/**
	 * Konstruktor
	 *
	 * @return ePruefung
	 */
	public function __construct()
	{
		parent::AbstractStudIPAdministrationPlugin();

		#$this->setPluginiconname('img/meinesem.gif');
		$this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates');
		$this->user = $this->getUser();
        $path = $GLOBALS['ABSOLUTE_URI_STUDIP'].str_replace($GLOBALS['ABSOLUTE_PATH_STUDIP'], '', dirname(__FILE__));
        $GLOBALS['_include_additional_header'] .= '<script src="'.$path.'/js/archiv.js" type="text/javascript"></script>'."\n";
	}

	/**
	 * Enter description here...
	 *
	 * @param string $newpath
	 */
	public function setPluginpath($newpath)
	{
		parent::setPluginpath($newpath);
		$this->buildMenu();
	}

	/**
	 * Erzeugt einen neuen Menpunkt in der Admin-Navigation
	 *
	 */
	public function buildMenu()
	{
		if ($this->user->getPermission()->hasRootPermission())
		{
			$tab = new PluginNavigation();
			$tab->setDisplayname(_('Archivierung von Veranstaltungen'));
			$this->setNavigation($tab);
			$this->setTopNavigation($tab);
		}
	}

	/**
	 * Enter description here...
	 *
	 * @return string Pluginname
	 */
	public function getPluginname()
	{
		return _('ArchivierungsPlugin');
	}

	/**
	 * Zeigt auf allen Seiten die ePrfung Subnavigation
	 *
	 */
	private function showMenue()
	{
		// Hier kommen die Links hin...
		$links = array
		(
			'manualArchiv' => PluginEngine::getURL($this, array(), 'manualArchiv'),
			'protectCourses' => PluginEngine::getURL($this, array(), 'protectCourses'),
			'configAutoArchiv' => PluginEngine::getURL($this, array(), 'configAutoArchiv'),
			'listArchiv' => PluginEngine::getURL($this, array(), 'listArchiv'),
			'listBrokenArchiv' => PluginEngine::getURL($this, array(), 'listBrokenArchiv')
		);
		$template = $this->template_factory->open('menue');
		$template->set_attribute('links', $links);
		echo $template->render();
	}

	/**
	 * Hauptfunktion. Zeigt eine bersichtsseite an und so...
	 *
	 */
	public function actionshow()
	{
		$this->actionmanualArchiv();
	}

	/**
	 * Enter description here...
	 *
	 */
	public function actionmanualArchiv()
	{
    	$this->showMenue();

		//Kurse anzeigen
		if(!empty($_REQUEST['action']) && $_REQUEST['action'] == 'manualsearch')
		{
		    $courses = ArchivDB::getCourses($_REQUEST['institut'], $_REQUEST['semester'], $this->getLastActivity(), $_REQUEST['duration'], $_REQUEST['semclass']);
            if(count($courses) == 0){
                echo Messagebox::info('Es wurden keine Veranstaltungen mit diesen Kriterien zum Archivieren gefunden.');
                $template = $this->template_factory->open('manual_get');
                $template->set_attribute('institutes', ArchivDB::getInstitutesByFaculty());
                $template->set_attribute('semesters', ArchivDB::getSemesters());
                $template->set_attribute('infobox', $this->getInfobox('2'));
            } else {
                $_SESSION['archivierungsplugin']['semclass'] = $_REQUEST['semclass'];
    		    $template = $this->template_factory->open('manual_show');
    			$template->set_attribute('institut', $_REQUEST['institut']);
    			$template->set_attribute('institut_name', ArchivDB::getInstitutName($_REQUEST['institut']));
    			$template->set_attribute('semester', $_REQUEST['semester']);
    			$template->set_attribute('semester_name', ArchivDB::getSemesterName($_REQUEST['semester']));
    			$template->set_attribute('inaktiv', $this->getLastActivity());
    			$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'manualArchiv'));
    			$template->set_attribute('courses', $courses);
            }
		}
		//Kurse archivieren
		elseif(Request::get('action') == 'manualarchiv')
		{
			//lieber nochmal rechte checken!
			if ($this->user->getPermission()->hasRootPermission())
			{
				//nur bestimmte
				if (Request::submitted('doArchive')) {
					$template = $this->template_factory->open('manual_result');
					$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'manualArchiv'));
					echo $template->render();
					ArchivDB::doArchiveCourses($_REQUEST['selectedCourses'], $_REQUEST['semester']);
					#$template->set_attribute('results', $results);
					return;

				}
				//oder alle
				elseif (Request::submitted('doArchiveAll')) {
					$template = $this->template_factory->open('manual_result');
					$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'manualArchiv'));
					echo $template->render();
					ArchivDB::doArchiveAllCourses($_REQUEST['institut'], $_REQUEST['semester'], $_REQUEST['inaktiv'], $_SESSION['archivierungsplugin']['semclass']);
					#$template->set_attribute('results', $results);
					return;
				}
				else {
					echo Messagebox::error('Keine gltige Archivierungsfunktion benutzt.');
					$template = $this->template_factory->open('manual_get');
					$template->set_attribute('institutes', ArchivDB::getInstitutesByFaculty());
					$template->set_attribute('semesters', ArchivDB::getSemesters());
					$template->set_attribute('infobox', $this->getInfobox('2'));
				}
			}
			else
			{
				echo Messagebox::error('Sie haben nicht die Rechte, diese Veranstaltungen zu archivieren.');
				return;
			}
		}
		//Standardansicht
		else
		{
			$template = $this->template_factory->open('manual_get');
			$template->set_attribute('institutes', ArchivDB::getInstitutesByFaculty());
			$template->set_attribute('semesters', ArchivDB::getSemesters());
			$template->set_attribute('infobox', $this->getInfobox('2'));
		}
		echo $template->render();
	}

	/**
	 * Zeigt die bersicht zum Schtzen von Veranstaltungen vor dem Archivieren
	 *
	 */
	public function actionprotectCourses()
	{
		$this->showMenue();

		//Kurse anzeigen
		if(!empty($_REQUEST['action']) && $_REQUEST['action'] == 'protectsearch')
		{
			$template = $this->template_factory->open('protect_show');
			$template->set_attribute('institut', $_REQUEST['institut']);
			$template->set_attribute('institut_name', ArchivDB::getInstitutName($_REQUEST['institut']));
			$template->set_attribute('semester', $_REQUEST['semester']);
			$template->set_attribute('semester_name', ArchivDB::getSemesterName($_REQUEST['semester']));
			$template->set_attribute('inaktiv', $this->getLastActivity());
			$template->set_attribute('courses', ArchivDB::getCourses($_REQUEST['institut'], $_REQUEST['semester'], $this->getLastActivity(), $_REQUEST['duration'], $_REQUEST['semclass']));
		}
		//Kurse schtzen
		elseif(!empty($_REQUEST['action']) && $_REQUEST['action'] == 'protectcourses')
		{
			//nur ausgewhlte
			if(!empty($_REQUEST['doNotArchive']))
			{
				$results = ArchivDB::protectCourses($_REQUEST['selectedCourses']);
			}
			//alle
			elseif(!empty($_REQUEST['doNotArchiveAll']))
			{
				$results = ArchivDB::protectAllCourses($_REQUEST['institut'], $_REQUEST['semester'], $_REQUEST['inaktiv']);
			}
			$template = $this->template_factory->open('protect_result');
			$template->set_attribute('results', $results);
		}
		//Standardansicht
		else
		{
			$template = $this->template_factory->open('protect_get');
			$template->set_attribute('institutes', ArchivDB::getInstitutesByFaculty());
			$template->set_attribute('semesters', ArchivDB::getSemesters());
			$template->set_attribute('infobox', $this->getInfobox('4'));
		}
		$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'protectCourses'));
		echo $template->render();
	}

	/**
	 * Zeigt die Konfigurationswerte an und bietet Mglichkeiten diese Einstellungen zu verndern.
	 *
	 */
	public function actionconfigAutoArchiv()
	{
		$this->showMenue();
		$template = $this->template_factory->open('config');
		$template->set_attribute('count_semester', ArchivDB::countSemester());
		$template->set_attribute('count_courses', ArchivDB::countCourses());
		$template->set_attribute('lastChange', ArchivDB::getLastArchivDate());
		$template->set_attribute('count_files', ArchivDB::countFiles());
		$template->set_attribute('count_boards', ArchivDB::countBoards());
		$template->set_attribute('count_wikis', ArchivDB::countWikis());
		$template->set_attribute('semesters', ArchivDB::getSemesters());
		$template->set_attribute('infobox', $this->getInfobox('1'));
		echo $template->render();
	}

	/**
	 * Zeigt eine Liste aller archivierten Veranstaltungen an
	 * und bietet die Funktion archivierte Veranstaltungen endgltig zu lschen.
	 *
	 */
	public function actionlistArchiv()
	{
		$this->showMenue();

		// veranstaltungen lschen
		if($_REQUEST['action'] == 'deletecourses')
		{
			$name = 'selectedCourses'.$_REQUEST['index'];
			$courses = $_REQUEST[$name];
			$template = $this->template_factory->open('delete_result');
			$template->set_attribute('results', ArchivDB::deleteCourses($courses));
			$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'listArchiv'));
		}
		// archiv anzeigen
		else
		{
			$template = $this->template_factory->open('list_archiv');
			$template->set_attribute('link', PluginEngine::getURL($this, array(), 'listArchiv'));
			$template->set_attribute('semesters', ArchivDB::getArchivedSemesters());
			//semester ausgewhlt
			if(!empty($_REQUEST['semester']))
			{
				$template->set_attribute('semester', $_REQUEST['semester']);
				$template->set_attribute('pluginpfad', $this->getPluginpath());
				$template->set_attribute('list', ArchivDB::getArchivedCourses($_REQUEST['semester']));
			}
		}
		echo $template->render();
	}

	/**
	 * Enter description here...
	 *
	 */
	public function actionlistBrokenArchiv()
	{
		$this->showMenue();

		// veranstaltungen lschen
		if($_REQUEST['action'] == 'deletecourses')
		{
			$template = $this->template_factory->open('delete_result');
			$template->set_attribute('results', ArchivDB::deleteCourses($_REQUEST['selectedCourses']));
			$template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'listBrokenArchiv'));
		}
		// archiv anzeigen
		else
		{
			$template = $this->template_factory->open('list_brokenarchiv');
			$template->set_attribute('list', ArchivDB::getBrokenCourses());
		}
		echo $template->render();
	}


	/**
	 * Enter description here...
	 *
	 * @return int
	 */
	private function getLastActivity()
	{
		//inaktivittszeitraum
		if ($_REQUEST['lastActivity_2'] == "monat")
		{
			$months = 1;
		}
		elseif ($_REQUEST['lastActivity_2'] == "jahr")
		{
			$months = 12;
		}
		else
		{
			echo Messagebox::error('Es wurde kein Inaktivittszeitraum angegeben. Bitte versuchen Sie es erneut.');
			return false;
		}
		return (mktime() - ($_REQUEST['lastActivity_1'] * $months * 60*60*24*31));
	}

	/**
	 * Gibt je nach id die passende Infobox aus
	 *
	 * @param int $id
	 * @return array $infobox
	 */
	private function getInfobox($id = '1')
	{
		// Infobox
		if($id == '1')
		{
	 		$infobox = array(
				array("kategorie" => _("Information:"),
					"eintrag" => array(
						/*array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Hier knnen Sie die automatische Archivierung konfigurieren. Geben Sie dazu die betreffenden Semester, das Datum der letzten Aktivitt, sowie das Datum zum Durchfhren der Archivierung an.'
						),*/
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'In der Statistik erhalten Sie einen berblick ber die Archivierung.'
						)
					)
				)
	 		);
		}
		elseif($id == '2')
		{
	 		$infobox = array(
				array("kategorie" => _("Information:"),
					"eintrag" => array(
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Whlen Sie die Einrichtung, die Semester und den Inaktivittszeitraum aus. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Wenn Sie eine Fakultt auswhlen, werden auch alle zugehrigen Institute ausgewhlt.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine Archivierung nicht rckgngig gemacht werden kann.'
						)
					)
				)
	 		);
		}
		elseif($id == '3')
		{
	 		$infobox = array(
				array("kategorie" => _("Information:"),
					"eintrag" => array(
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Whlen Sie die Einrichtung aus. Die anderen Parameter kommen aus der Konfiguration der automatischen Archivierung. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Die Auflistung der Veranstaltungen kann je nach Menge sehr lange dauern.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine Archivierung nicht rckgngig gemacht werden kann.'
						)
					)
				)
	 		);
		}
		elseif($id == '4')
		{
	 		$infobox = array(
				array("kategorie" => _("Information:"),
					"eintrag" => array(
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Whlen Sie die Einrichtung, die Semester und den Inaktivittszeitraum aus. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => 'Die Auflistung der Veranstaltungen kann je nach Menge sehr lange dauern.'
						),
						array(
							"icon" => '../../'.$this->getPluginpath().'/img/information.png',
							"text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine beim Schtzen der Veranstaltungen das Datum der letzten Aktivitt auf heute gesetzt wird und nicht rckgngig gemacht werden kann.'
						)
					)
				)
	 		);
		}
		return $infobox;
	}
}
?>